"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var platform_1 = require("tns-core-modules/platform");
var FFmpegActions;
(function (FFmpegActions) {
    FFmpegActions["EXECUTE"] = "execute";
    FFmpegActions["EXECUTEWITHARGUMENTS"] = "executeWithArguments";
    FFmpegActions["GETFFMPEGVERSION"] = "ffmpegVersion";
    FFmpegActions["GETPLATFORM"] = "platform";
    FFmpegActions["CANCEL"] = "cancel";
    FFmpegActions["GETMEDIAINFORMATION"] = "mediaInformation";
    FFmpegActions["LOG"] = "log";
    FFmpegActions["STATISTICS"] = "statistics";
    FFmpegActions["GETEXTERNALLIBRARIES"] = "externalLibraries";
    FFmpegActions["GETLASTRECEIVEDSTATISTICS"] = "lastReceivedStatistics";
    FFmpegActions["GETLASTRETURNCODE"] = "lastReturnCode";
    FFmpegActions["GETLASTCOMMANDOUTPUT"] = "lastCommandOutput";
    FFmpegActions["ENABLELOG"] = "enableLog";
    FFmpegActions["ENABLESTATISTICS"] = "enableStatistics";
})(FFmpegActions = exports.FFmpegActions || (exports.FFmpegActions = {}));
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["AV_LOG_QUIET"] = -8] = "AV_LOG_QUIET";
    LogLevel[LogLevel["AV_LOG_PANIC"] = 0] = "AV_LOG_PANIC";
    LogLevel[LogLevel["AV_LOG_FATAL"] = 8] = "AV_LOG_FATAL";
    LogLevel[LogLevel["AV_LOG_ERROR"] = 16] = "AV_LOG_ERROR";
    LogLevel[LogLevel["AV_LOG_WARNING"] = 24] = "AV_LOG_WARNING";
    LogLevel[LogLevel["AV_LOG_INFO"] = 32] = "AV_LOG_INFO";
    LogLevel[LogLevel["AV_LOG_VERBOSE"] = 40] = "AV_LOG_VERBOSE";
    LogLevel[LogLevel["AV_LOG_DEBUG"] = 48] = "AV_LOG_DEBUG";
    LogLevel[LogLevel["AV_LOG_TRACE"] = 56] = "AV_LOG_TRACE";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
var FFmpeg = (function () {
    function FFmpeg() {
    }
    Object.defineProperty(FFmpeg, "worker", {
        get: function () {
            var _this = this;
            if (!this._worker) {
                if (global['TNS_WEBPACK']) {
                    var FFmpegWorker = require('nativescript-worker-loader!./worker');
                    this._worker = new FFmpegWorker();
                }
                else {
                    this._worker = new Worker('./worker');
                }
                this._worker.onmessage = function (msg) {
                    var id = msg.data.id;
                    var action = msg.data.action;
                    var type = msg.data.type;
                    var result = msg.data.result;
                    var callback = _this.callbackMap.get(id);
                    if (callback) {
                        if (type === 'success') {
                            switch (action) {
                                case FFmpegActions.CANCEL:
                                    callback.resolve();
                                    break;
                                case FFmpegActions.EXECUTE:
                                case FFmpegActions.EXECUTEWITHARGUMENTS:
                                case FFmpegActions.GETFFMPEGVERSION:
                                case FFmpegActions.GETPLATFORM:
                                case FFmpegActions.GETMEDIAINFORMATION:
                                case FFmpegActions.GETEXTERNALLIBRARIES:
                                case FFmpegActions.GETLASTCOMMANDOUTPUT:
                                case FFmpegActions.GETLASTRECEIVEDSTATISTICS:
                                case FFmpegActions.GETLASTRETURNCODE:
                                    callback.resolve(result);
                                    break;
                                default:
                                    break;
                            }
                        }
                        else {
                            callback.reject(result);
                        }
                    }
                    else if (action === FFmpegActions.LOG) {
                        if (!_this._logCallback) {
                            console.log(result);
                        }
                        else {
                            _this._logCallback(result);
                        }
                    }
                    else if (FFmpegActions.STATISTICS) {
                        if (_this._statisticsCallback) {
                            _this._statisticsCallback(result);
                        }
                    }
                };
                this._worker.onerror = function (error) {
                    console.error(error);
                };
            }
            return this._worker;
        },
        enumerable: true,
        configurable: true
    });
    FFmpeg.execute = function (cmd, delimiter) {
        var _this = this;
        if (delimiter === void 0) { delimiter = ' '; }
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.execute(cmd, delimiter, new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({
                    action: FFmpegActions.EXECUTE,
                    cmd: cmd,
                    delimiter: delimiter,
                    id: id
                });
            }
        });
    };
    FFmpeg.executeWithArguments = function (args) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.executeWithArguments(args, new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({
                    action: FFmpegActions.EXECUTEWITHARGUMENTS,
                    args: args,
                    id: id
                });
            }
        });
    };
    FFmpeg.getFFmpegVersion = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.getFFmpegVersion(new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({ action: FFmpegActions.GETFFMPEGVERSION, id: id });
            }
        });
    };
    FFmpeg.getPlatform = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.getPlatform(new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({ action: FFmpegActions.GETPLATFORM, id: id });
            }
        });
    };
    FFmpeg.cancel = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.cancel(new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({ action: FFmpegActions.CANCEL, id: id });
            }
        });
    };
    FFmpeg.getMediaInformation = function (file, timeOut) {
        var _this = this;
        if (timeOut === void 0) { timeOut = 10000; }
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.getMediaInformation(file, java.lang.Long.valueOf(timeOut), new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        try {
                            resolve(JSON.parse(result));
                        }
                        catch (e) {
                            console.error(e);
                            resolve(result);
                        }
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({
                    action: FFmpegActions.GETMEDIAINFORMATION,
                    file: file,
                    id: id,
                    timeOut: timeOut
                });
            }
        });
    };
    FFmpeg.disableRedirection = function () {
        if (platform_1.isAndroid) {
            com.arthenica.mobileffmpeg.Config.disableRedirection();
        }
        else {
            MobileFFmpegConfig.disableRedirection();
        }
    };
    FFmpeg.enableRedirection = function () {
        if (platform_1.isAndroid) {
            com.arthenica.mobileffmpeg.Config.enableRedirection();
        }
        else {
            MobileFFmpegConfig.enableRedirection();
        }
    };
    FFmpeg.getLogLevel = function () {
        if (platform_1.isAndroid) {
            return com.arthenica.mobileffmpeg.Config.getLogLevel().getValue();
        }
        else {
            return MobileFFmpegConfig.getLogLevel();
        }
    };
    FFmpeg.setLogLevel = function (level) {
        if (platform_1.isAndroid) {
            com.arthenica.mobileffmpeg.Config.setLogLevel(com.arthenica.mobileffmpeg.Level.from(level.valueOf()));
        }
        else {
            MobileFFmpegConfig.setLogLevel(level.valueOf());
        }
    };
    FFmpeg.disableLogs = function () {
        if (platform_1.isAndroid) {
            com.arthenica.mobileffmpeg.Config.enableLogCallback(null);
        }
        else {
            MobileFFmpegConfig.setLogDelegate(null);
        }
    };
    FFmpeg.disableStatistics = function () {
        if (platform_1.isAndroid) {
            com.arthenica.mobileffmpeg.Config.enableStatisticsCallback(null);
        }
        else {
            MobileFFmpegConfig.setStatisticsDelegate(null);
        }
    };
    FFmpeg.enableLogCallback = function (callback) {
        if (platform_1.isAndroid) {
            com.github.triniwiz.fancyffmpeg.FancyFFmpeg.enableLogCallback(new com.github.triniwiz.fancyffmpeg.LogListener({
                onResult: function (result) {
                    try {
                        var data = JSON.parse(result);
                        if (callback) {
                            callback(data);
                        }
                        else {
                            console.log(data);
                        }
                    }
                    catch (e) {
                        if (callback) {
                            callback(result);
                        }
                        else {
                            console.error(e);
                        }
                    }
                }
            }));
        }
        else {
            this.worker.postMessage({ action: FFmpegActions.ENABLELOG });
            if (!callback) {
                this._logCallback = null;
                return;
            }
            this._logCallback = callback;
        }
    };
    FFmpeg.enableStatisticsCallback = function (callback) {
        if (platform_1.isAndroid) {
            com.github.triniwiz.fancyffmpeg.FancyFFmpeg.enableStatisticsCallback(new com.github.triniwiz.fancyffmpeg.LogListener({
                onResult: function (result) {
                    if (callback) {
                        try {
                            callback(JSON.parse(result));
                        }
                        catch (e) {
                            callback(result);
                        }
                    }
                }
            }));
        }
        else {
            this.worker.postMessage({ action: FFmpegActions.ENABLESTATISTICS });
            if (!callback) {
                this._statisticsCallback = null;
                return;
            }
            this._statisticsCallback = callback;
        }
    };
    FFmpeg.resetStatistics = function () {
        if (platform_1.isAndroid) {
            com.arthenica.mobileffmpeg.Config.resetStatistics();
        }
        else {
            MobileFFmpegConfig.resetStatistics();
        }
    };
    FFmpeg.getExternalLibraries = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.getExternalLibraries(new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({
                    action: FFmpegActions.GETEXTERNALLIBRARIES,
                    id: id
                });
            }
        });
    };
    FFmpeg.getLastReceivedStatistics = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.getLastReceivedStatistics(new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        try {
                            resolve(JSON.parse(result));
                        }
                        catch (e) {
                            resolve(result);
                        }
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({
                    action: FFmpegActions.GETLASTRECEIVEDSTATISTICS,
                    id: id
                });
            }
        });
    };
    FFmpeg.getLastReturnCode = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.getLastReturnCode(new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({
                    action: FFmpegActions.GETLASTRETURNCODE,
                    id: id
                });
            }
        });
    };
    FFmpeg.getLastCommandOutput = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (platform_1.isAndroid) {
                com.github.triniwiz.fancyffmpeg.FancyFFmpeg.getLastCommandOutput(new com.github.triniwiz.fancyffmpeg.Listener({
                    onError: function (error) {
                        reject(error);
                    },
                    onSuccess: function (result) {
                        resolve(result);
                    }
                }));
            }
            else {
                var id = _this.getUUID();
                _this.callbackMap.set(id, { resolve: resolve, reject: reject });
                _this.worker.postMessage({
                    action: FFmpegActions.GETLASTCOMMANDOUTPUT,
                    id: id
                });
            }
        });
    };
    FFmpeg.setFontDirectory = function () {
    };
    FFmpeg.setFontconfigConfigurationPath = function () {
    };
    FFmpeg.getUUID = function () {
        if (platform_1.isAndroid) {
            return java.util.UUID.randomUUID().toString();
        }
        else {
            return NSUUID.UUID().UUIDString;
        }
    };
    FFmpeg.callbackMap = new Map();
    return FFmpeg;
}());
exports.FFmpeg = FFmpeg;
//# sourceMappingURL=ffmpeg.js.map