"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("tns-core-modules/globals");
var platform_1 = require("tns-core-modules/platform");
var ffmpeg_1 = require("./ffmpeg");
var main_queue;
if (!platform_1.isAndroid) {
    main_queue = dispatch_get_current_queue();
}
var context = self;
context.onmessage = function (msg) {
    switch (msg.data.action) {
        case ffmpeg_1.FFmpegActions.EXECUTE:
            execute(msg.data.cmd, msg.data.delimiter, msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.EXECUTEWITHARGUMENTS:
            executeWithArguments(msg.data.args, msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.GETFFMPEGVERSION:
            getFFmpegVersion(msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.GETPLATFORM:
            getPlatform(msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.CANCEL:
            cancel(msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.GETMEDIAINFORMATION:
            getMediaInformation(msg.data.file, msg.data.id, msg.data.timeOut);
            break;
        case ffmpeg_1.FFmpegActions.GETEXTERNALLIBRARIES:
            getExternalLibraries(msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.GETLASTRETURNCODE:
            getLastReturnCode(msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.GETLASTRECEIVEDSTATISTICS:
            getLastReceivedStatistics(msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.GETLASTCOMMANDOUTPUT:
            getLastCommandOutput(msg.data.id);
            break;
        case ffmpeg_1.FFmpegActions.ENABLELOG:
            initLogListener();
            break;
        case ffmpeg_1.FFmpegActions.ENABLESTATISTICS:
            initStatisticsListener();
            break;
        default:
            break;
    }
};
var initLogListener = function () {
    if (platform_1.isAndroid) {
    }
    else {
        var logDelegateImpl = NSObject.extend({
            logCallback: function (level, message) {
                dispatch_async(main_queue, function () {
                    context.postMessage({
                        type: 'success',
                        action: ffmpeg_1.FFmpegActions.LOG,
                        result: { level: level, text: message }
                    });
                });
            }
        }, { name: 'LogDelegateImpl', protocols: [LogDelegate] });
        MobileFFmpegConfig.setLogDelegate(logDelegateImpl.new());
    }
};
var initStatisticsListener = function () {
    if (platform_1.isAndroid) {
    }
    else {
        var statsDelegateImpl = NSObject.extend({
            statisticsCallback: function (statistics) {
                dispatch_async(main_queue, function () {
                    context.postMessage({
                        type: 'success',
                        action: ffmpeg_1.FFmpegActions.STATISTICS,
                        result: {
                            bitrate: statistics.getBitrate(),
                            size: statistics.getSize(),
                            speed: statistics.getSpeed(),
                            time: statistics.getTime(),
                            videoFps: statistics.getVideoFps(),
                            videoFrameNumber: statistics.getVideoFrameNumber(),
                            videoQuality: statistics.getVideoQuality()
                        }
                    });
                });
            }
        }, {
            name: 'StatisticsDelegateImpl',
            protocols: [StatisticsDelegate]
        });
        MobileFFmpegConfig.setStatisticsDelegate(statsDelegateImpl.new());
    }
};
var initListeners = function () {
    initLogListener();
    initStatisticsListener();
};
var execute = function (cmd, delimiter, id) {
    if (delimiter === void 0) { delimiter = null; }
    try {
        var result = void 0;
        if (platform_1.isAndroid) {
            if (!delimiter || delimiter === ' ') {
                result = com.arthenica.mobileffmpeg.FFmpeg.execute(cmd);
            }
            else {
                result = com.arthenica.mobileffmpeg.FFmpeg.execute(cmd, delimiter);
            }
        }
        else {
            if (!delimiter || delimiter === ' ') {
                result = MobileFFmpeg.execute(cmd);
            }
            else {
                result = MobileFFmpeg.executeDelimiter(cmd, delimiter);
            }
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.EXECUTE, type: 'success', result: result, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.EXECUTE, type: 'error', result: e.message, id: id });
    }
};
var executeWithArguments = function (args, id) {
    try {
        var result = void 0;
        if (platform_1.isAndroid) {
            result = com.arthenica.mobileffmpeg.FFmpeg.execute(args);
        }
        else {
            result = MobileFFmpeg.executeWithArguments(args);
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.EXECUTEWITHARGUMENTS, type: 'success', result: result, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.EXECUTEWITHARGUMENTS, type: 'error', result: e.message, id: id });
    }
};
var getFFmpegVersion = function (id) {
    try {
        var version = void 0;
        if (platform_1.isAndroid) {
            version = 'version ' + com.arthenica.mobileffmpeg.FFmpeg.getFFmpegVersion();
        }
        else {
            version = 'version ' + MobileFFmpeg.getFFmpegVersion();
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETFFMPEGVERSION, type: 'success', result: version, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETFFMPEGVERSION, type: 'error', result: e.message, id: id });
    }
};
var getPlatform = function (id) {
    try {
        var platform = void 0;
        if (platform_1.isAndroid) {
            platform = 'android-' + com.arthenica.mobileffmpeg.AbiDetect.getAbi();
        }
        else {
            platform = 'ios-' + ArchDetect.getArch();
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETPLATFORM, type: 'success', result: platform, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETPLATFORM, type: 'error', result: e.message, id: id });
    }
};
var cancel = function (id) {
    try {
        if (platform_1.isAndroid) {
            com.arthenica.mobileffmpeg.FFmpeg.cancel();
        }
        else {
            MobileFFmpeg.cancel();
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.CANCEL, type: 'success', id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.CANCEL, type: 'error', result: e.message, id: id });
    }
};
var getMediaInformation = function (file, id, timeOut) {
    try {
        var mediaInfo = void 0;
        if (platform_1.isAndroid) {
            var info = com.arthenica.mobileffmpeg.FFmpeg.getMediaInformation(file, timeOut);
            var streams = [];
            var nativeStreams = info.getStreams();
            if (nativeStreams) {
                var length_1 = nativeStreams.size();
                for (var i = 0; i < length_1; i++) {
                    var item = nativeStreams.get(i);
                    item.getAverageFrameRate();
                    streams.push({
                        id: item.getIndex(),
                        type: item.getType(),
                        codec: item.getCodec(),
                        fullCodec: item.getFullCodec(),
                        format: item.getFormat(),
                        fullFormat: item.getFullFormat(),
                        width: item.getWidth(),
                        height: item.getHeight(),
                        bitrate: item.getBitrate(),
                        sampleRate: item.getSampleRate(),
                        sampleFormat: item.getSampleFormat(),
                        channelLayout: item.getChannelLayout(),
                        sampleAspectRatio: item.getSampleAspectRatio(),
                        displayAspectRatio: item.getDisplayAspectRatio(),
                        averageFrameRate: item.getAverageFrameRate(),
                        realFrameRate: item.getRealFrameRate(),
                        timeBase: item.getTimeBase(),
                        codecTimeBase: item.getCodecTimeBase()
                    });
                }
            }
            mediaInfo = {
                bitrate: info.getBitrate().longValue(),
                duration: info.getDuration().longValue(),
                format: info.getFormat(),
                path: info.getPath(),
                startTime: info.getStartTime().longValue(),
                rawInformation: info.getRawInformation(),
                streams: streams
            };
            context.postMessage({ action: ffmpeg_1.FFmpegActions.GETMEDIAINFORMATION, type: 'success', id: id, result: mediaInfo });
        }
        else {
            var info = MobileFFmpeg.getMediaInformationTimeout(file, timeOut);
            var streams = [];
            var nativeStreams = info.getStreams();
            if (nativeStreams) {
                var length_2 = nativeStreams.count;
                for (var i = 0; i < length_2; i++) {
                    var item = nativeStreams.objectAtIndex(i);
                    item.getAverageFrameRate();
                    streams.push({
                        id: item.getIndex(),
                        type: item.getType(),
                        codec: item.getCodec(),
                        fullCodec: item.getFullCodec(),
                        format: item.getFormat(),
                        fullFormat: item.getFullFormat(),
                        width: item.getWidth(),
                        height: item.getHeight(),
                        bitrate: item.getBitrate(),
                        sampleRate: item.getSampleRate(),
                        sampleFormat: item.getSampleFormat(),
                        channelLayout: item.getChannelLayout(),
                        sampleAspectRatio: item.getSampleAspectRatio(),
                        displayAspectRatio: item.getDisplayAspectRatio(),
                        averageFrameRate: item.getAverageFrameRate(),
                        realFrameRate: item.getRealFrameRate(),
                        timeBase: item.getTimeBase(),
                        codecTimeBase: item.getCodecTimeBase()
                    });
                }
            }
            mediaInfo = {
                bitrate: info.getBitrate(),
                duration: info.getDuration(),
                format: info.getFormat(),
                path: info.getPath(),
                startTime: info.getStartTime(),
                rawInformation: info.getRawInformation(),
                streams: streams
            };
            context.postMessage({ action: ffmpeg_1.FFmpegActions.GETMEDIAINFORMATION, type: 'success', id: id, result: mediaInfo });
        }
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETMEDIAINFORMATION, type: 'error', result: e.message, id: id });
    }
};
var getExternalLibraries = function (id) {
    try {
        var libs = [];
        if (platform_1.isAndroid) {
            libs = com.arthenica.mobileffmpeg.Config.getExternalLibraries().toArray();
        }
        else {
            var nativeLibs = MobileFFmpegConfig.getExternalLibraries();
            var count = nativeLibs.count;
            for (var i = 0; i < count; i++) {
                libs.push(nativeLibs.objectAtIndex(i));
            }
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETEXTERNALLIBRARIES, type: 'success', result: libs, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETEXTERNALLIBRARIES, type: 'error', result: e.message, id: id });
    }
};
var getLastReturnCode = function (id) {
    try {
        var code = void 0;
        if (platform_1.isAndroid) {
            code = com.arthenica.mobileffmpeg.FFmpeg.getLastReturnCode();
        }
        else {
            code = MobileFFmpeg.getLastReturnCode();
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETLASTRETURNCODE, type: 'success', result: code, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETLASTRETURNCODE, type: 'error', result: e.message, id: id });
    }
};
var getLastReceivedStatistics = function (id) {
    try {
        var stats = void 0;
        if (platform_1.isAndroid) {
            var statistics = com.arthenica.mobileffmpeg.Config.getLastReceivedStatistics();
            stats = {
                bitrate: statistics.getBitrate(),
                size: statistics.getSize(),
                speed: statistics.getSpeed(),
                time: statistics.getTime(),
                videoFps: statistics.getVideoFps(),
                videoFrameNumber: statistics.getVideoFrameNumber(),
                videoQuality: statistics.getVideoQuality()
            };
        }
        else {
            var statistics = MobileFFmpegConfig.getLastReceivedStatistics();
            stats = {
                bitrate: statistics.getBitrate(),
                size: statistics.getSize(),
                speed: statistics.getSpeed(),
                time: statistics.getTime(),
                videoFps: statistics.getVideoFps(),
                videoFrameNumber: statistics.getVideoFrameNumber(),
                videoQuality: statistics.getVideoQuality()
            };
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETLASTRECEIVEDSTATISTICS, type: 'success', result: stats, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETLASTRECEIVEDSTATISTICS, type: 'error', result: e.message, id: id });
    }
};
var getLastCommandOutput = function (id) {
    try {
        var output = void 0;
        if (platform_1.isAndroid) {
            output = com.arthenica.mobileffmpeg.FFmpeg.getLastCommandOutput();
        }
        else {
            output = MobileFFmpeg.getLastCommandOutput();
        }
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETLASTCOMMANDOUTPUT, type: 'success', result: output, id: id });
    }
    catch (e) {
        context.postMessage({ action: ffmpeg_1.FFmpegActions.GETLASTCOMMANDOUTPUT, type: 'error', result: e.message, id: id });
    }
};
initListeners();
context.onerror = function (error) {
    console.error('worker error :- ', error);
};
//# sourceMappingURL=worker.js.map